pub fn volume_strength_modifier(context: &VolumeContext, category: &str) -> f64Expand description
Return a strength modifier for a given volume context and strategy category.
Values > 1.0 amplify the signal; values < 1.0 dampen it.
pub fn volume_strength_modifier(context: &VolumeContext, category: &str) -> f64Return a strength modifier for a given volume context and strategy category.
Values > 1.0 amplify the signal; values < 1.0 dampen it.